@@ -43,8 +43,7 @@ def extraradiation(datetime_or_doy, solar_constant=1366.1, method='spencer',
 
     Parameters
     ----------
-    datetime_or_doy : int, float, array, date, datetime, datetime64,
-                      Timestamp, DatetimeIndex
+    datetime_or_doy : numeric, array, date, datetime, Timestamp, DatetimeIndex
         Day of year, array of days of year, or datetime-like object
 
     solar_constant : float
@@ -628,7 +627,7 @@ def klucher(surface_tilt, surface_azimuth, dhi, ghi, solar_zenith,
     cos_tt = aoi_projection(surface_tilt, surface_azimuth,
                             solar_zenith, solar_azimuth)
 
-    F = 1 - ((ghi / ghi) ** 2)
+    F = 1 - ((dhi / ghi) ** 2)
     try:
         # fails with single point input
         F.fillna(0, inplace=True)
